@@ -158,13 +158,25 @@ public class ParsedSentence extends Atom implements Serializable
 	}
 
 	/**
-	 * Return the i'th word in the sentence, as a string
+	 * Return the i'th lemmatized word in the sentence, as a string.
+	 * This is the "root form" of the word, and not the original word.
 	 */
 	public String getWord(int i)
 	{
 		return LinkableView.getWordString(getWordAsNode(i));
 	}
 
+	/**
+	 * Return the i'th word in the sentence, as a string
+	 * This is the original form of the word, and not its lemma.
+	 */
+	public String getOrigWord(int i)
+	{
+		FeatureNode fn = getWordAsNode(i).get("orig_str");
+		if (fn == null) return null;
+		return fn.getValue();
+	}
+
 	public void addWord(FeatureNode w)
 	{
 		leafConstituents.add(w);
@@ -328,12 +340,15 @@ public class ParsedSentence extends Atom implements Serializable
 	 * The ranking will be stored as the "confidence" of the 
 	 * TruthValue associated with this parse.
 	 *
+	 * @returns the score that was assigned.
+	 *
 	 * A classic example of competing parses for a sentence is:
 	 * (S (NP I) (VP saw (NP the man) (PP with (NP the binoculars))) .)
 	 * (S (NP I) (VP saw (NP (NP the man) (PP with (NP the binoculars)))) .)
 	 * The ranker below gives both about equal scores.
+	 *
 	 */
-	public void simpleRankParse()
+	public double simpleRankParse()
 	{
 		SimpleTruthValue stv = new SimpleTruthValue();
 		truth_value = stv;
@@ -351,8 +366,22 @@ public class ParsedSentence extends Atom implements Serializable
 		weight = Math.exp(-weight);
 
 		stv.setConfidence(weight);
+		return weight;
 	}
 	
+	/**
+	 * Take the current parse confidence, and rescale it by the 
+	 * indicated amount.  The method simpleRankParse() must have
+	 * been previously called to perform the initial ranking.
+	 */
+	public void rescaleRank(double weight)
+	{
+		SimpleTruthValue stv = (SimpleTruthValue) truth_value;
+		double confidence = stv.getConfidence();
+		confidence *= weight;
+		stv.setConfidence(confidence);
+	}
+
 	public int hashCode()
 	{
 		if (original == null)
