@@ -21,6 +21,7 @@ import java.io.InputStreamReader;
 import java.util.ArrayList;
 import java.util.HashSet;
 import java.util.Map;
+import java.util.TreeMap;
 
 import relex.algs.SentenceAlgorithmApplier;
 import relex.anaphora.Antecedents;
@@ -100,7 +101,15 @@ public class RelationExtractor
 	/* ---------------------------------------------------------- */
 	/* Constructors, etc. */
 
+	public RelationExtractor()
+	{
+		init(false);
+	}
 	public RelationExtractor(boolean useSocket)
+	{
+		init(useSocket);
+	}
+	private void init(boolean useSocket)
 	{
 		parser = new LinkParser();
 
@@ -121,6 +130,13 @@ public class RelationExtractor
 		do_anaphora_resolution = false;
 
 		stats = new ParseStats();
+		sumtime = new TreeMap<String,Long>();
+		cnttime = new TreeMap<String,Long>(); 
+	}
+
+	String getVersion()
+	{
+		return context.getLinkParserClient().getVersion();
 	}
 
 	/* ---------------------------------------------------------- */
@@ -177,37 +193,48 @@ public class RelationExtractor
 		                               new ArrayList<EntityInfo>());
 		}
 
-		RelexInfo ri = parseSentence(sentence, entityMaintainer);
-
-		for (ParsedSentence parse : ri.getParses())
+		RelexInfo ri = null;
+		try
 		{
-			// Markup feature node graph with entity info,
-			// so that the relex algs (next step) can see them.
-			entityMaintainer.prepareSentence(parse.getLeft());
+			if (verbosity > 0) starttime = System.currentTimeMillis();
+			ri = parseSentence(sentence, entityMaintainer);
+			if (verbosity > 0) reportTime("Link-parsing: ");
 
-			// The actual relation extraction is done here.
-			sentenceAlgorithmApplier.applyAlgs(parse, context);
+			for (ParsedSentence parse : ri.getParses())
+			{
+				// Markup feature node graph with entity info,
+				// so that the relex algs (next step) can see them.
+				entityMaintainer.prepareSentence(parse.getLeft());
 
-			// Strip out the entity markup, so that when the
-			// sentence is printed, we don't print gunk.
-			entityMaintainer.repairSentence(parse.getLeft());
+				// The actual relation extraction is done here.
+				sentenceAlgorithmApplier.applyAlgs(parse, context);
 
-			// Also do a Penn tree-bank style phrase structure markup.
-			phraseMarkup.markup(parse);
+				// Strip out the entity markup, so that when the
+				// sentence is printed, we don't print gunk.
+				entityMaintainer.repairSentence(parse.getLeft());
 
-			// Repair the entity-mangled tree-bank string.
-			PhraseTree pt = new PhraseTree(parse.getLeft());
-			parse.setPhraseString(pt.toString());
+				// Also do a Penn tree-bank style phrase structure markup.
+				phraseMarkup.markup(parse);
+
+				// Repair the entity-mangled tree-bank string.
+				PhraseTree pt = new PhraseTree(parse.getLeft());
+				parse.setPhraseString(pt.toString());
+			}
 
 			// Assign a simple parse-ranking score, based on LinkGrammar data.
-			parse.simpleRankParse();
-		}
+			ri.simpleParseRank();
 
-		// Perform anaphora resolution
-		if (do_anaphora_resolution)
+			// Perform anaphora resolution
+			if (do_anaphora_resolution)
+			{
+				hobbs.addParse(ri);
+				hobbs.resolve(ri);
+			}
+		}
+		catch(Exception e)
 		{
-			hobbs.addParse(ri);
-			hobbs.resolve(ri);
+			System.err.println("Failed to process sentence: " + sentence);
+			System.err.println(e.toString());
 		}
 		if (verbosity > 0) reportTime("Relex processing: ");
 		return ri;
@@ -231,6 +258,7 @@ public class RelationExtractor
 		if (sentence.length() < DEFAULT_MAX_SENTENCE_LENGTH) {
 			ri = parser.parse(sentence, context.getLinkParserClient());
 		} else {
+			System.err.println("Sentence too long!: " + sentence);
 			ri = new RelexInfo();
 		}
 		ri.setSentence(orig_sentence);
@@ -240,13 +268,30 @@ public class RelationExtractor
 	/* ---------------------------------------------------------- */
 	// Provide some basic timing info
 	Long starttime;
+	TreeMap<String,Long> sumtime; 
+	TreeMap<String,Long> cnttime; 
 
 	private void reportTime(String msg)
 	{
 		Long now = System.currentTimeMillis();
 		Long elapsed = now - starttime;
 		starttime = now;
-		System.out.println(msg + elapsed + " millseconds");
+
+		Long sum = sumtime.get(msg);
+		Long cnt = cnttime.get(msg);
+		if (sum == null)
+		{
+			sum = 0L;
+			cnt = 0L;
+		}
+		cnt ++;
+		sum += elapsed;
+		sumtime.put(msg, sum);
+		cnttime.put(msg, cnt);
+
+		Long avg = sum / cnt;
+		System.err.println(msg + elapsed + " milliseconds (avg=" 
+			+ avg + " millisecs, cnt=" + cnt + ")");
 	}
 
 	/* --------------------------------------------------------- */
@@ -330,20 +375,20 @@ public class RelationExtractor
 		Map<String,String> commandMap = CommandLineArgParser.parse(args, opts, flags);
 
 		String sentence = null;
-		int maxParses = 30;
-		int maxParseSeconds = 60;
+		int maxParses = 1;
+		int maxParseSeconds = 6;
 
 		// Check for optional command line arguments.
 		try
 		{
-			maxParses = commandMap.get("-n") != null ?
-				Integer.parseInt(commandMap.get("-n").toString()) : 1;
+			String opt = commandMap.get("-s");
+			if (opt != null) sentence = opt;
 
-			sentence = commandMap.get("-s") != null ?
-				commandMap.get("-s").toString() : null;
+			opt = commandMap.get("-n");
+			if (opt != null) maxParses = Integer.parseInt(opt);
 
-			maxParseSeconds = commandMap.get("--maxParseSeconds") != null ?
-				Integer.parseInt(commandMap.get("--maxParseSeconds").toString()) : 60;
+			opt = commandMap.get("--maxParseSeconds");
+			if (opt != null) maxParseSeconds = Integer.parseInt(opt);
 		}
 		catch (Exception e)
 		{
