@@ -1,4 +1,3 @@
-package relex.parser;
 /*
  * Copyright 2008 Novamente LLC
  *
@@ -15,6 +14,8 @@ package relex.parser;
  * limitations under the License.
  */
 
+package relex.parser;
+
 import java.util.ArrayList;
 
 import relex.RelexProperties;
@@ -84,6 +85,10 @@ public class LinkParserSocketClient extends LinkParserClient
 		return response;
 	}
 
+	public String getVersion() {
+		return exec(LinkParserProtocol.MSG_GET_VERSION);
+	}
+
 	public void setMaxParseSeconds(int maxParseSeconds) {
 		super.setMaxParseSeconds(maxParseSeconds);
 		exec(LinkParserProtocol.MSG_SET_MAX_PARSE_SECONDS + maxParseSeconds);
@@ -113,7 +118,7 @@ public class LinkParserSocketClient extends LinkParserClient
 	}
 
 	public void close() {
-		client.process(LinkParserProtocol.MSG_CLOSE, null);
+		client.process(LinkParserProtocol.MSG_KILL_SYSTEM, null);
 	}
 
 	void execParse(String sentence) {
